terraform {
  required_providers {
    rancher2 = {
      source  = "local/providers/rancher2"
      version = "1.0.0"
    }
  }
}

provider "rancher2" {
  api_url   = var.rancher_api_url
  token_key = var.rancher_admin_bearer_token
  insecure  = true
}



resource "rancher2_cluster" "felipe-rke" {
  name = var.rke_cluster_name
  rke_config {
    kubernetes_version = "v1.26.4-rancher2-1"
    enable_cri_dockerd = true
    network {
      plugin = var.rke_network_plugin
    }
    services {
      etcd {
        creation = "6h"
        retention = "72h"
      }
    }
    ingress {
      default_backend = "false"
    }
  }
  cluster_auth_endpoint {}
  cluster_agent_deployment_customization {
    append_tolerations {
      effect = "NoSchedule"
      key    = "tolerate/control-plane"
      value  = "true"
    }
  override_affinity = <<EOF
{
  "nodeAffinity": {
    "requiredDuringSchedulingIgnoredDuringExecution": {
      "nodeSelectorTerms": [{
        "matchExpressions": [{
          "key": "beta.kubernetes.io/os",
          "operator": "NotIn",
          "values": [
            "windows"
          ]
        }]
      }]
    }
  }
}
EOF
    override_resource_requirements {
      cpu_limit      = "800m"
      cpu_request    = "250m"
      memory_limit   = "800Mi"
      memory_request = "250Mi"
    }
  }
  fleet_agent_deployment_customization {
    append_tolerations {
      effect = "NoSchedule"
      key    = "tolerate/worker"
      value  = "true"
    }
  }

}


// TODO - Default DO Credential not working?
//  Error creating machine: Error in driver during machine creation: POST https://api.digitalocean.com/v2/droplets: 422 You specified an invalid image for Droplet creation.
resource "rancher2_node_template" "rancher2_node_template_do" {
  name = var.rke_node_template_name
  digitalocean_config {
    access_token  = var.do_token
    backups =false
    image = "ubuntu-22-04-x64"
    ipv6 =false
    monitoring = false
    private_networking = false
    region = "nyc3"
    size = "s-2vcpu-4gb-intel"
    ssh_key_fingerprint=	""
    ssh_port = "22"
    ssh_user =	"root"
    tags =""
    userdata= ""
  }
}

resource "rancher2_node_pool" "pool1" {
  cluster_id       = rancher2_cluster.felipe-rke.id
  name             = "pool1"
  hostname_prefix  = "tf-rke-pool1-"
  node_template_id = rancher2_node_template.rancher2_node_template_do.id
  quantity         = 1
  control_plane    = true
  etcd             = true 
  worker           = true 
}
